# Changelog

## 0.3.0

* Switched to struqture 2.0 (struqture 2.0.0-alpha.11).
**NOTE**: struqture-qutip-interface now **outputs struqture 2.0 objects**.

## 0.2.0

### Updated in 0.2.0

* Updated to qutip 5.0

## 0.1.2

### Fixed in 0.1.2

* Pinned to `qutip>=4,<5` for compatibility reasons

## 0.1.1

### Updated in 0.1.1

* Updated to new workflows

## 0.1.0

### Added in 0.1.0

* Initial version of the struqture-qutip-interface